/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.web.utils;

import org.wso2.registry.secure.SecureRegistry;
import org.wso2.registry.RegistryException;
import org.wso2.registry.RegistryConstants;
import org.wso2.registry.ActionConstants;
import org.wso2.registry.web.actions.ResourceDetailsAction;
import org.wso2.registry.web.UIConstants;
import org.wso2.usermanager.Realm;
import org.wso2.usermanager.AccessControlAdmin;
import org.wso2.usermanager.UserManagerException;
import org.wso2.usermanager.UserManagerConstants;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.ServletException;
import java.io.IOException;

public class PermissionUtil {

    public static void applyMassUserPermissions(
            HttpServletRequest request, HttpServletResponse response)
            throws RegistryException, ServletException, IOException {

        String permissionString = request.getParameter("permissionInput");
        String resourcePath = request.getParameter("resourcePath");

        SecureRegistry secureRegistry = CommonUtil.getUserRegistry(request);
        Realm realm = secureRegistry.getUserRealm();

        AccessControlAdmin accessControlAdmin = null;
        try {
            accessControlAdmin = realm.getAccessControlAdmin();
        } catch (UserManagerException e) {
            String msg = "Couldn't get access control admin for changing authorizations. Caused by: " + e.getMessage();
            throw new RegistryException(msg);
        }

        try {

            String[] userPermissions = permissionString.split("1");
            for (int i = 0; i < userPermissions.length; i++) {

                if (userPermissions[i].trim().length() == 0) {
                    continue;
                }

                String[] permissions = userPermissions[i].split("2");
                String permUser = permissions[0];

                if (!(permUser.equals(RegistryConstants.SYSTEM_USER) ||
                        permUser.equals(RegistryConstants.ADMIN_USER))) {

                    accessControlAdmin.clearUserAuthorization(permUser, resourcePath, ActionConstants.GET);
                    accessControlAdmin.clearUserAuthorization(permUser, resourcePath, ActionConstants.PUT);
                    accessControlAdmin.clearUserAuthorization(permUser, resourcePath, ActionConstants.DELETE);
                    accessControlAdmin.clearUserAuthorization(permUser, resourcePath, UserManagerConstants.AUTHORIZE);
                }

                for (int j = 1; j < permissions.length; j++) {
                    String[] permission = permissions[j].split("3");

                    String action = permission[0];
                    String checked = permission[1];

                    if (action.equals("ra")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.authorizeUser(permUser, resourcePath, ActionConstants.GET);
                        }
                    } else if (action.equals("rd")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.denyUser(permUser, resourcePath, ActionConstants.GET);
                        }
                    } else if (action.equals("wa")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.authorizeUser(permUser, resourcePath, ActionConstants.PUT);
                        }
                    } else if (action.equals("wd")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.denyUser(permUser, resourcePath, ActionConstants.PUT);
                        }
                    } else if (action.equals("da")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.authorizeUser(permUser, resourcePath, ActionConstants.DELETE);
                        }
                    } else if (action.equals("dd")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.denyUser(permUser, resourcePath, ActionConstants.DELETE);
                        }
                    } else if (action.equals("aa")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.authorizeUser(permUser, resourcePath, UserManagerConstants.AUTHORIZE);
                        }
                    } else if (action.equals("ad")) {
                        if (checked.equals("true")) {
                            accessControlAdmin.denyUser(permUser, resourcePath, UserManagerConstants.AUTHORIZE);
                        }
                    }
                }
            }
        } catch (UserManagerException e) {
            String msg = "Couldn't set authorizations. Caused by: " + e.getMessage();
            throw new RegistryException(msg);
        }

        ResourceDetailsAction resourceDetailsAction = new ResourceDetailsAction();
        resourceDetailsAction.setPath(resourcePath);
        resourceDetailsAction.execute(request);

        request.getSession().setAttribute(UIConstants.RESOURCE_BEAN, resourceDetailsAction);
        request.getRequestDispatcher(UIConstants.AJAX_PERMISSIONS_JSP).forward(request, response);
    }
}
